package org.example;

import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

/**
 * @author lwy
 */
public class Main {
    public static void main(String[] args) {
        // 获取今天的日期，并将其格式化为 "yyyy-MM-dd" 的字符串
        LocalDate today = LocalDate.now();
        String dateStr = today.format(DateTimeFormatter.ofPattern("M.d"));

        // 创建今天日期的目录
        Path dirPath = Paths.get("X:\\" + dateStr);
        createFolder(dirPath);

        // 在目录下创建三个子目录
        String[] dirs = {"pic", "pic - 副本", "video", "修改后"};
        for (String subdir : dirs) {
            Path subdirPath = Paths.get(dirPath.toString(), subdir);
            createFolder(subdirPath);
        }

        // 在目录下创建一个以今天日期命名的txt文件
        Path filePath = Paths.get(dirPath.toString(), dateStr + ".txt");
        if (Files.exists(filePath)) {
            System.out.println("File already exists: " + filePath);
        } else {
            try {
                Files.createFile(filePath);
                System.out.println("File created: " + filePath);
            } catch (IOException e) {
                System.out.println("Failed to create file: " + e.getMessage());
            }
        }

        // 在video目录下创建一个转换视频文件
        InputStream inputStream = Main.class.getClassLoader().getResourceAsStream("fastConvertMPG2mp4.bat");
        Path videoConvertFile = Paths.get(dirPath + "\\video").resolve("fastConvertMPG2mp4.bat");

        if (Files.exists(videoConvertFile)) {
            System.out.println("File already exists: " + videoConvertFile);
        } else {
            try {
                if (inputStream != null) {
                    Files.copy(inputStream, videoConvertFile, StandardCopyOption.REPLACE_EXISTING);
                }
//                Files.copy(sourcePath, videoConvertFile);
                System.out.println("File created: " + videoConvertFile);
            } catch (IOException e) {
                System.out.println("Failed to create file: " + e.getMessage());
            }
        }

        System.out.println("文件夹和文件创建结束！！！");
    }

    static void createFolder(Path subdirPath) {
        if (Files.exists(subdirPath)) {
            System.out.println("Directory already exists: " + subdirPath);
        } else {
            try {
                Files.createDirectory(subdirPath);
                System.out.println("Directory created: " + subdirPath);
            } catch (IOException e) {
                System.out.println("Failed to create directory: " + e.getMessage());
            }
        }
    }
}